@@ -7,12 +7,15 @@ import multiprocessing as mp
 import gc
 
 
-def move_files(source_dir, chunk, dest_dir, chunk_name):
+def move_files(source_dir, chunk, dest_dir, chunk_name, sub_directory: str = None):
     for file_path in chunk:
         try:
             file_pathlib = Path(file_path)
             filename = file_pathlib.stem + file_pathlib.suffix
-            dest_path = Path(dest_dir) / chunk_name / filename
+            if sub_directory is None or sub_directory == "":
+                dest_path = Path(dest_dir) / chunk_name / filename
+            else:
+                dest_path = Path(dest_dir) / chunk_name / sub_directory / filename
             scr_dir = str(Path(source_dir) / filename)
             if Path(scr_dir).is_file():
                 shutil.copy(scr_dir, str(dest_path))
@@ -23,7 +26,7 @@ def move_files(source_dir, chunk, dest_dir, chunk_name):
 
 
 def chunk_files(raw_dataset, dest_dir: str,
-                number_chunk: int, multithread=True, chunk_index_to_copy=None):
+                number_chunk: int, multithread=True, chunk_index_to_copy=None, sub_directory: str = None):
     with raw_dataset.mount() as mount_context:
         all_documents_flatten_dir = mount_context.mount_point
         files_list = [str(p) for p in Path(all_documents_flatten_dir).iterdir() if p.is_file()]
@@ -35,7 +38,10 @@ def chunk_files(raw_dataset, dest_dir: str,
         if chunk_index_to_copy is not None and index not in chunk_index_to_copy:
             continue
         chunk_name = "chunk" + str(index)
-        dir_path = Path(str(Path(dest_dir) / chunk_name))
+        if sub_directory is None or sub_directory == "":
+            dir_path = Path(str(Path(dest_dir) / chunk_name))
+        else:
+            dir_path = Path(str(Path(dest_dir) / chunk_name / sub_directory))
         dir_path.mkdir(parents=True, exist_ok=True)
         start = time.time()
 
@@ -52,7 +58,7 @@ def chunk_files(raw_dataset, dest_dir: str,
                     pool = mp.Pool(number_cpus)
                     csv_files_chuncks = numpy.array_split(sub_chunk, number_cpus)
                     try:
-                        pool.starmap(move_files, [(all_documents_flatten_dir, row, dest_dir, chunk_name) for row in
+                        pool.starmap(move_files, [(all_documents_flatten_dir, row, dest_dir, chunk_name, sub_directory) for row in
                                                   csv_files_chuncks])
                     except Exception:
                         print("Unexpected error:", sys.exc_info()[0])
